@@ -1,4 +1,7 @@
+from pathlib import Path
+
 import pytest
+from dirty_equals import IsIgnoreDict
 from executing import is_pytest_compatible
 
 from inline_snapshot import snapshot
@@ -37,7 +40,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
     assert result.report == snapshot(
         """\
 ------------------------------- Create snapshots -------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -4,4 +4,4 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -84,7 +87,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
     assert result.report == snapshot(
         """\
 -------------------------------- Fix snapshots ---------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -4,4 +4,4 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -133,7 +136,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
     assert result.report == snapshot(
         """\
 ------------------------------- Update snapshots -------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -4,4 +4,4 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -178,7 +181,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
     assert result.report == snapshot(
         """\
 -------------------------------- Trim snapshots --------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -4,4 +4,4 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -237,7 +240,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
     assert result.report == snapshot(
         """\
 -------------------------------- Fix snapshots ---------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -6,4 +6,4 @@                                                              |
 |                                                                              |
 |  def test_a():                                                               |
@@ -248,7 +251,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 +------------------------------------------------------------------------------+
 These changes will be applied, because you used fix
 -------------------------------- Trim snapshots --------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -5,5 +5,5 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -314,7 +317,7 @@ show-updates=true
     assert result.report == snapshot(
         """\
 -------------------------------- Fix snapshots ---------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -6,4 +6,4 @@                                                              |
 |                                                                              |
 |  def test_a():                                                               |
@@ -327,7 +330,7 @@ These changes are not applied.
 Use --inline-snapshot=fix to apply them, or use the interactive mode with
 --inline-snapshot=review
 -------------------------------- Trim snapshots --------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -5,5 +5,5 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -339,7 +342,7 @@ Use --inline-snapshot=fix to apply them, or use the interactive mode with
 +------------------------------------------------------------------------------+
 These changes will be applied, because you used trim
 ------------------------------- Update snapshots -------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -4,6 +4,6 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -535,7 +538,7 @@ def test_something():
     assert result.report == snapshot(
         """\
 -------------------------------- Fix snapshots ---------------------------------
-+-------------------------------- test_file.py --------------------------------+
++----------------------------- tests/test_file.py -----------------------------+
 | @@ -4,4 +4,4 @@                                                              |
 |                                                                              |
 |                                                                              |
@@ -592,8 +595,9 @@ ERROR test_file.py::test_sub_snapshot - Failed: your snapshot is missing one val
 ============================================================================ ERRORS ============================================================================
 ____________________________________________________________ ERROR at teardown of test_sub_snapshot ____________________________________________________________
 your snapshot is missing one value.
+If you just created this value with --snapshot=create, the value is now created and you can ignore this message.
 =================================================================== short test summary info ====================================================================
-ERROR test_file.py::test_sub_snapshot - Failed: your snapshot is missing one value.
+ERROR tests/test_file.py::test_sub_snapshot - Failed: your snapshot is missing one value.
 ================================================================== 1 passed, 1 error in <time> ==================================================================
 """
         )
@@ -611,7 +615,7 @@ def test_persist_unknown_external(project):
 from inline_snapshot import external, snapshot
 
 def test_sub_snapshot():
-    external("123*.png")
+    external("hash:123*.png")
     assert 1==snapshot(2)
 """
     )
@@ -623,7 +627,7 @@ def test_sub_snapshot():
 from inline_snapshot import external, snapshot
 
 def test_sub_snapshot():
-    external("123*.png")
+    external("hash:123*.png")
     assert 1==snapshot(1)
 """
     )
@@ -635,13 +639,13 @@ def test_diff_multiple_files():
 
     Example(
         {
-            "test_a.py": """
+            "tests/test_a.py": """
 from inline_snapshot import snapshot
 
 def test_a():
     assert 1==snapshot(2)
     """,
-            "test_b.py": """
+            "tests/test_b.py": """
 from inline_snapshot import snapshot
 
 def test_b():
@@ -652,28 +656,28 @@ def test_b():
         ["--inline-snapshot=create,fix"],
         changed_files=snapshot(
             {
-                "test_b.py": """\
-
-from inline_snapshot import snapshot
-
-def test_b():
-    assert 1==snapshot(1)
-    \
-""",
-                "test_a.py": """\
+                "tests/test_a.py": """\
 
 from inline_snapshot import snapshot
 
 def test_a():
     assert 1==snapshot(1)
     \
+""",
+                "tests/test_b.py": """\
+
+from inline_snapshot import snapshot
+
+def test_b():
+    assert 1==snapshot(1)
+    \
 """,
             }
         ),
         report=snapshot(
             """\
 ------------------------------- Create snapshots -------------------------------
-+--------------------------------- test_b.py ----------------------------------+
++------------------------------ tests/test_b.py -------------------------------+
 | @@ -2,5 +2,5 @@                                                              |
 |                                                                              |
 |  from inline_snapshot import snapshot                                        |
@@ -684,7 +688,7 @@ def test_a():
 +------------------------------------------------------------------------------+
 These changes will be applied, because you used create
 -------------------------------- Fix snapshots ---------------------------------
-+--------------------------------- test_a.py ----------------------------------+
++------------------------------ tests/test_a.py -------------------------------+
 | @@ -2,5 +2,5 @@                                                              |
 |                                                                              |
 |  from inline_snapshot import snapshot                                        |
@@ -792,44 +796,66 @@ def test_a():
 def test_storage_dir_config(project, tmp_path, storage_dir):
     # Relative path case: `tests/snapshots` (parametrized).
     # Absolute path case: `tmp_path / "snapshots"` (parametrized as `None`).
+    relative = storage_dir is not None
+
     if not storage_dir:
         storage_dir = tmp_path / "snapshots"
 
-    project.pyproject(
-        f"""
+    external_value = snapshot("hello")
+
+    Example(
+        {
+            "pyproject.toml": f"""\
 [tool.inline-snapshot]
 storage-dir = {str(storage_dir)!r}
-"""
-    )
-
-    project.setup(
-        """
+""",
+            "test_a.py": """\
 from inline_snapshot import outsource, snapshot
 
 def test_outsource():
-    assert outsource("hello", suffix=".html") == snapshot()
-"""
-    )
-
-    result = project.run("--inline-snapshot=create")
-    assert result.ret == 1
-    assert project.source == snapshot(
-        """\
+    assert outsource("hello") == snapshot()
+""",
+        }
+    ).run_pytest(
+        ["--inline-snapshot=create"],
+        changed_files=IsIgnoreDict(
+            {
+                "test_a.py": snapshot(
+                    """\
 from inline_snapshot import outsource, snapshot
 
 from inline_snapshot import external
 
 def test_outsource():
-    assert outsource("hello", suffix=".html") == snapshot(external("2cf24dba5fb0*.html"))
+    assert outsource("hello") == snapshot(external("hash:2cf24dba5fb0*.txt"))
 """
+                ),
+                "tests/snapshots/external/2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b9824.txt": (
+                    external_value if relative else None
+                ),
+            }
+        ),
+        returncode=1,
+    ).run_pytest(
+        ["--inline-snapshot=disable"], returncode=0, changed_files=snapshot({})
+    ).run_pytest(
+        ["--inline-snapshot=fix"], returncode=0, changed_files=snapshot({})
     )
 
-    result = project.run("--inline-snapshot=fix")
-    assert result.ret == 0
+    # assert result.ret == 0
 
-    assert project.storage(storage_dir) == snapshot(
-        ["2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b9824.html"]
-    )
+    if not relative:
+        assert {
+            p.name: p.read_text() for p in (Path(storage_dir) / "external").iterdir()
+        } == snapshot(
+            {
+                ".gitignore": """\
+# ignore all snapshots which are not referred in the source
+*-new.*
+""",
+                "2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b9824.txt": external_value,
+            }
+        )
 
 
 def test_find_pyproject_in_parent_directories():
@@ -852,12 +878,46 @@ def test_something():
         ["--rootdir", "./project", "--inline-snapshot=create"],
         changed_files=snapshot(
             {
+                "project/.inline-snapshot/external/9f86d081884c7d659a2feaa0c55ad015a3bf4f1b2b0b822cd15d6c15b0f00a08.txt": "test",
                 "project/test_something.py": """\
 from inline_snapshot import outsource,snapshot,external
 
 def test_something():
-    assert outsource("test") == snapshot(external("9f*.txt"))
-"""
+    assert outsource("test") == snapshot(external("hash:9f*.txt"))
+""",
+            }
+        ),
+        returncode=1,
+    )
+
+
+def test_find_pyproject_in_workspace_project():
+
+    Example(
+        {
+            "sub_project/pyproject.toml": """\
+[tool.inline-snapshot]
+hash-length=2
+""",
+            "pyproject.toml": "[tool.pytest.ini_options]",
+            "sub_project/test_something.py": """\
+from inline_snapshot import outsource,snapshot,external
+
+def test_something():
+    assert outsource("test") == snapshot()
+""",
+        }
+    ).run_pytest(
+        ["--rootdir", "./sub_project", "--inline-snapshot=create"],
+        changed_files=snapshot(
+            {
+                "sub_project/.inline-snapshot/external/9f86d081884c7d659a2feaa0c55ad015a3bf4f1b2b0b822cd15d6c15b0f00a08.txt": "test",
+                "sub_project/test_something.py": """\
+from inline_snapshot import outsource,snapshot,external
+
+def test_something():
+    assert outsource("test") == snapshot(external("hash:9f*.txt"))
+""",
             }
         ),
         returncode=1,
@@ -881,7 +941,7 @@ def test_a():
         report=snapshot(
             """\
 -------------------------------- Fix snapshots ---------------------------------
-+----------------------------- test_something.py ------------------------------+
++-------------------------- tests/test_something.py ---------------------------+
 | @@ -2,4 +2,4 @@                                                              |
 |                                                                              |
 |  from inline_snapshot import snapshot                                        |
@@ -918,7 +978,7 @@ def test_a():
         report=snapshot(
             """\
 -------------------------------- Fix snapshots ---------------------------------
-+----------------------------- test_something.py ------------------------------+
++-------------------------- tests/test_something.py ---------------------------+
 | @@ -2,4 +2,4 @@                                                              |
 |                                                                              |
 |  from inline_snapshot import snapshot                                        |
@@ -934,7 +994,7 @@ Do you want to fix these snapshots? [y/n] (n):\
         stderr=snapshot(""),
         changed_files=snapshot(
             {
-                "test_something.py": """\
+                "tests/test_something.py": """\
 import pytest
 from inline_snapshot import snapshot
 
@@ -945,3 +1005,24 @@ def test_a():
         ),
         stdin=b"y\n",
     )
+
+
+def test_pytest_configure_exception():
+
+    Example(
+        {
+            "conftest.py": """
+import pytest
+def pytest_configure(config: pytest.Config) -> None:
+
+    pytest.exit(
+        reason="failed",
+        returncode=pytest.ExitCode.INTERRUPTED,
+    )
+""",
+            "test_a.py": """
+def test_a():
+    pass
+             """,
+        }
+    ).run_pytest(stderr=snapshot("Exit: failed"), returncode=snapshot(2))
